# CHANGELOG

<!-- version list -->

## v0.1.0-alpha.24 (2025-08-12)

### Bug Fixes

- Papertrail_search_logs configurable timeout [SC-33981]
  ([#74](https://github.com/aptible/unpage/pull/74),
  [`6674d88`](https://github.com/aptible/unpage/commit/6674d88afd88a1cedbbe6bd7d12f92dd16742472))


## v0.1.0-alpha.23 (2025-08-12)

### Bug Fixes

- **deps**: Depend on our own (non-pre-release) version of dspy
  ([#81](https://github.com/aptible/unpage/pull/81),
  [`23fe079`](https://github.com/aptible/unpage/commit/23fe0795e8623c294057b452789322f35848bb57))


## v0.1.0-alpha.22 (2025-08-11)

### Bug Fixes

- **deps**: Clean up dependencies and eliminate vendored packages
  ([#78](https://github.com/aptible/unpage/pull/78),
  [`87fec00`](https://github.com/aptible/unpage/commit/87fec001635be5881d46050ad77d671ab4f09b27))


## v0.1.0-alpha.21 (2025-08-08)

### Documentation

- Add pagerduty_resolve_incident tool [SC-34309] ([#59](https://github.com/aptible/unpage/pull/59),
  [`76c2960`](https://github.com/aptible/unpage/commit/76c29607a0ba4f18b9e9f96599da5ee9627eaf7d))

- Fix typo on command reference ([#58](https://github.com/aptible/unpage/pull/58),
  [`97ee5db`](https://github.com/aptible/unpage/commit/97ee5dbe036b134cbe524187cecfa75ecc2394f3))

- Update docs with recent changes to subcommand arguments
  ([#39](https://github.com/aptible/unpage/pull/39),
  [`fff21d0`](https://github.com/aptible/unpage/commit/fff21d0ed9b6cbe5f74c59836cd15a5e2a8f1087))

### Features

- Aws instance status tools [SC-33981] ([#60](https://github.com/aptible/unpage/pull/60),
  [`f32d4ad`](https://github.com/aptible/unpage/commit/f32d4ade25776608b7d0301224da6353450ba65e))


## v0.1.0-alpha.20 (2025-08-07)

### Bug Fixes

- [sc-34008] Support arguments in EDITOR env variable
  ([#42](https://github.com/aptible/unpage/pull/42),
  [`ea20f91`](https://github.com/aptible/unpage/commit/ea20f919ae2ac7188ab774d39f7ac52cc59bb0d3))

### Documentation

- Add links to generate tokens for datadog, pagerduty, papertrail [SC-34055]
  ([#54](https://github.com/aptible/unpage/pull/54),
  [`7121649`](https://github.com/aptible/unpage/commit/712164978a9934aba17d75bb50692159b47d2dac))

- Update community anchor text ([#56](https://github.com/aptible/unpage/pull/56),
  [`85547b3`](https://github.com/aptible/unpage/commit/85547b3a77b9a0b3d1c63512a6b3b0820949e955))


## v0.1.0-alpha.19 (2025-08-04)

### Features

- Simplify llm configuration and provide more links! [SC-34094] [SC-34097]
  ([#41](https://github.com/aptible/unpage/pull/41),
  [`953a488`](https://github.com/aptible/unpage/commit/953a4889992b3a64f2f855dfcc576c80bf92464d))


## v0.1.0-alpha.18 (2025-07-31)

### Features

- Add `pagerduty_resolve_incident` tool [sc-34092]
  ([#38](https://github.com/aptible/unpage/pull/38),
  [`daed569`](https://github.com/aptible/unpage/commit/daed569f8b9b2ae3eba4153d5bc7c17d635dfeea))


## v0.1.0-alpha.17 (2025-07-30)

### Bug Fixes

- Pin pydantic and remove duplicate dependencies to support `--prerelease allow`
  ([#37](https://github.com/aptible/unpage/pull/37),
  [`44e1ba3`](https://github.com/aptible/unpage/commit/44e1ba3499d59c33ca838108504a93955adbcbef))


## v0.1.0-alpha.16 (2025-07-30)

### Documentation

- Add logo images ([#33](https://github.com/aptible/unpage/pull/33),
  [`4ac78f2`](https://github.com/aptible/unpage/commit/4ac78f25f71a6ca73d12b57503ff3e12d15005e7))

- Add unpage favicon ([#35](https://github.com/aptible/unpage/pull/35),
  [`9d10084`](https://github.com/aptible/unpage/commit/9d1008491b7d7bd5542da29546fb6460951be46f))

- Community links ([#32](https://github.com/aptible/unpage/pull/32),
  [`dc35b72`](https://github.com/aptible/unpage/commit/dc35b721109aa74c074494ee406054ddc89dd28f))

### Features

- Suppress all the warnings all the time [SC-34071]
  ([#36](https://github.com/aptible/unpage/pull/36),
  [`62f5ab8`](https://github.com/aptible/unpage/commit/62f5ab87afca2d33bfdbb36a9abd24e1435e83b7))


## v0.1.0-alpha.15 (2025-07-29)

### Features

- More telemetry [SC-34016] ([#30](https://github.com/aptible/unpage/pull/30),
  [`65cf118`](https://github.com/aptible/unpage/commit/65cf1189e3746c91cf495ad5c534bb469d9a8c8a))


## v0.1.0-alpha.14 (2025-07-29)

### Bug Fixes

- Reduce *_search_logs() response sizes [SC-34056]
  ([#29](https://github.com/aptible/unpage/pull/29),
  [`1cd488b`](https://github.com/aptible/unpage/commit/1cd488bacd0efbec9dc7bc7734b4682c3a0b65c7))

### Features

- Telemetry [SC-34016] [SC-33944] ([#21](https://github.com/aptible/unpage/pull/21),
  [`496c017`](https://github.com/aptible/unpage/commit/496c01772e0323282b14f74d372f49c55e619203))


## v0.1.0-alpha.13 (2025-07-29)

### Features

- Intuitive subcommand structure [SC-34058] ([#19](https://github.com/aptible/unpage/pull/19),
  [`142cdcf`](https://github.com/aptible/unpage/commit/142cdcf86109183a5c120bca6eca736aaaf064b2))


## v0.1.0-alpha.12 (2025-07-29)

### Documentation

- Add helpful links to Getting Started ([#23](https://github.com/aptible/unpage/pull/23),
  [`be9a2f0`](https://github.com/aptible/unpage/commit/be9a2f03b3ff497a3f37aef6ee2416d102e0605a))

### Features

- Simplify llm configuration [SC-34069] [SC-34066]
  ([#31](https://github.com/aptible/unpage/pull/31),
  [`6e7dce4`](https://github.com/aptible/unpage/commit/6e7dce41440974263f7615a186bdad79e5ad66f2))


## v0.1.0-alpha.11 (2025-07-29)

### Bug Fixes

- Vendor dspy and drain3 dependencies ([#28](https://github.com/aptible/unpage/pull/28),
  [`3f25c8d`](https://github.com/aptible/unpage/commit/3f25c8d3c4bea2e5d74d49d81ec5bca3d50e6d32))


## v0.1.0-alpha.10 (2025-07-28)

### Bug Fixes

- Oops broke uv build during release ([#27](https://github.com/aptible/unpage/pull/27),
  [`1904c71`](https://github.com/aptible/unpage/commit/1904c71cc97402b3307bb08410d1e96424a1119b))

- Update release to handle prerelease ([#25](https://github.com/aptible/unpage/pull/25),
  [`a70867d`](https://github.com/aptible/unpage/commit/a70867d1dfa8560385700f0ec41ea9aace2bceb2))


## v0.1.0-alpha.9 (2025-07-28)

### Bug Fixes

- Uv.lock was somehow missing its prerelease-mode?
  ([#24](https://github.com/aptible/unpage/pull/24),
  [`3a544fb`](https://github.com/aptible/unpage/commit/3a544fb72a24c888accd2a075b62ec71bb0adb0e))


## v0.1.0-alpha.8 (2025-07-28)

### Bug Fixes

- Unbreak dependencies ([#22](https://github.com/aptible/unpage/pull/22),
  [`03f7c72`](https://github.com/aptible/unpage/commit/03f7c72130bb37072c2e6df4023823322198a732))


## v0.1.0-alpha.7 (2025-07-28)

### Bug Fixes

- Match git behavior and us vim/vi when no EDITOR env var is set [SC-34065]
  ([#20](https://github.com/aptible/unpage/pull/20),
  [`e45a1f5`](https://github.com/aptible/unpage/commit/e45a1f5b2b1b0addcedb5aeb87f43a32a1e2cbfd))


## v0.1.0-alpha.6 (2025-07-28)

### Bug Fixes

- Ensure dspy and drain3 are installed from source [SC-34060]
  ([#18](https://github.com/aptible/unpage/pull/18),
  [`10be9aa`](https://github.com/aptible/unpage/commit/10be9aa393d230875600d00f485cc276fe9e6102))


## v0.1.0-alpha.5 (2025-07-28)

### Features

- Add dspy version to `unpage version` command [SC-34060]
  ([#17](https://github.com/aptible/unpage/pull/17),
  [`1377d35`](https://github.com/aptible/unpage/commit/1377d35553042e8300ee21619aadca64b469e0bd))

- Datadog log search mcp tool [SC-33638] ([#14](https://github.com/aptible/unpage/pull/14),
  [`72dfc64`](https://github.com/aptible/unpage/commit/72dfc6474e066e60d5b0120af4e3226249b83440))


## v0.1.0-alpha.4 (2025-07-28)

### Bug Fixes

- Graceful not found message when node_id does not exist in graph [SC-34003]
  ([#13](https://github.com/aptible/unpage/pull/13),
  [`e2393d2`](https://github.com/aptible/unpage/commit/e2393d2ff1a2f8c7a854a9068b87a820f8adfece))

### Documentation

- [sc-33936] [sc-33939] [sc-34001] Add Core Concepts and Command Reference docs
  ([#16](https://github.com/aptible/unpage/pull/16),
  [`b3c2f8f`](https://github.com/aptible/unpage/commit/b3c2f8feb859ed807f6cfb44f98db3b3ef89404c))

- Getting started - v1 ([#10](https://github.com/aptible/unpage/pull/10),
  [`672fac9`](https://github.com/aptible/unpage/commit/672fac9e7fd439a3d33ada6fa1012d2064d2e28e))


## v0.1.0-alpha.3 (2025-07-25)

### Bug Fixes

- Pin numba to also bring up llvmlite ([#12](https://github.com/aptible/unpage/pull/12),
  [`4649884`](https://github.com/aptible/unpage/commit/46498848e0bd9e5020ed3ad6c3a6bdbcc502bb7e))


## v0.1.0-alpha.2 (2025-07-25)

### Features

- Start on an Unpage mascot ([#8](https://github.com/aptible/unpage/pull/8),
  [`7f41a4d`](https://github.com/aptible/unpage/commit/7f41a4d3c42fde8f9bc3c04a6103e20c927855c3))


## v0.1.0-alpha.1 (2025-07-25)

### Features

- Add support for disabling telemetry ([#7](https://github.com/aptible/unpage/pull/7),
  [`037798c`](https://github.com/aptible/unpage/commit/037798cbaec8ded81b316762421f00ba3c2b1bae))


## v0.0.1-alpha.1 (2025-07-25)

- Initial Release
